==> haskell-hstringtemplate-0.8.8-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hstringtemplate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HStringTemplate
version:              0.8.8
visibility:           public
id:                   HStringTemplate-0.8.8-LL4pBImpTMQIsGrNXzkiyF
key:                  HStringTemplate-0.8.8-LL4pBImpTMQIsGrNXzkiyF
license:              BSD-3-Clause
maintainer:           s.clover@gmail.com
author:               Sterling Clover
synopsis:             StringTemplate implementation in Haskell.
description:          A port of the Java library by Terrence Parr.
category:             Text
abi:                  4370022b1e2c6ebb8cc40d4a8f0a03fe
exposed:              True
exposed-modules:
    Text.StringTemplate Text.StringTemplate.Base
    Text.StringTemplate.Classes Text.StringTemplate.GenericStandard
    Text.StringTemplate.QQ

hidden-modules:
    Text.StringTemplate.Instances Text.StringTemplate.Group
    Text.StringTemplate.Renderf

import-dirs:          /usr/lib/ghc-9.4.8/site-local/HStringTemplate-0.8.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HStringTemplate-0.8.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HStringTemplate-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hstringtemplate
hs-libraries:         HSHStringTemplate-0.8.8-LL4pBImpTMQIsGrNXzkiyF
depends:
    array-0.5.4.0 base-4.17.2.1
    blaze-builder-0.4.4.1-GC1i0mzFnQi6MqAUVTXmHq bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    mtl-2.2.2 old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh parsec-3.1.16.1
    pretty-1.1.3.6 syb-0.7.3-DvMMPSfjQylGDaZxljQ4qT
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:
    /usr/share/doc/haskell-hstringtemplate/html/HStringTemplate.haddock

haddock-html:         /usr/share/doc/haskell-hstringtemplate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hstringtemplate-0.8.8-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hstringtemplate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HStringTemplate
version:              0.8.8
visibility:           public
id:                   HStringTemplate-0.8.8-IXHdmVPf4BmFuWAwCShhlA
key:                  HStringTemplate-0.8.8-IXHdmVPf4BmFuWAwCShhlA
license:              BSD-3-Clause
maintainer:           s.clover@gmail.com
author:               Sterling Clover
synopsis:             StringTemplate implementation in Haskell.
description:          A port of the Java library by Terrence Parr.
category:             Text
abi:                  0b3b226cfaec837771d26adad1af2093
exposed:              True
exposed-modules:
    Text.StringTemplate Text.StringTemplate.Base
    Text.StringTemplate.Classes Text.StringTemplate.GenericStandard
    Text.StringTemplate.QQ

hidden-modules:
    Text.StringTemplate.Instances Text.StringTemplate.Group
    Text.StringTemplate.Renderf

import-dirs:          /usr/lib/ghc-9.4.8/site-local/HStringTemplate-0.8.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HStringTemplate-0.8.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HStringTemplate-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hstringtemplate
hs-libraries:         HSHStringTemplate-0.8.8-IXHdmVPf4BmFuWAwCShhlA
depends:
    array-0.5.4.0 base-4.17.2.1
    blaze-builder-0.4.4.1-BSmLbvNejToLEWeTg2SNQj bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    mtl-2.2.2 old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh parsec-3.1.16.1
    pretty-1.1.3.6 syb-0.7.3-8mb1dpoCL4AAb4S0Fpw3xy
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:
    /usr/share/doc/haskell-hstringtemplate/html/HStringTemplate.haddock

haddock-html:         /usr/share/doc/haskell-hstringtemplate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
